import requests


class Weather:
    """
    Creates a Weather object by getting the following as input: api-key, city name or latitude/longitude coordinates,
    temperature units (optional). If no units (metric / imperial) are given, kelvin units are applied as the default
    temperature units convention.
    """

    def __init__(self, api_key, city=None, lat=None, lon=None, units=None):
        if city:
            url = f"https://api.openweathermap.org/data/2.5/forecast?q={city}&appid={api_key}&units={units}"
            response = requests.get(url=url)
            self.data = response.json()
        elif lat and lon:
            url = f"https://api.openweathermap.org/data/2.5/forecast?lat={lat}&lon={lon}&appid={api_key}&units={units}"
            response = requests.get(url=url)
            self.data = response.json()
        else:
            raise TypeError('provide either a city name or latitude and longitude arguments.')

        if self.data['cod'] != '200':
            raise ValueError(self.data['message'])

    def next_24_hours(self):
        """
        Returns full 3-hour weather data for the next 24 hours as a dict.
        """
        return self.data['list'][:9]

    def next_24_hours_basic(self):
        """
        Returns 3-hour basic weather data (datetime, temperature, sky condition, sky condition icon code)
        for the next 24 hours as a list of tuples.
        """
        basic_data = []
        for item in self.data['list'][:9]:
            basic_data.append(
                (item['dt_txt'], item['main']['temp'], item['weather'][0]['description'].title(),
                 item['weather'][0]['icon'])
            )

        return basic_data



from setuptools import setup

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='appyweather',
    packages=['appyweather'],
    version='1.0.2',
    license='MIT',
    description='24h Weather Forecast Data',
    long_description=long_description,
    long_description_content_type="text/markdown",
    include_package_data=True,
    author='Kostas Deligiannis',
    author_email='pr0fil3r@gmail.com',
    url='https://example.com',
    keywords=['weather', 'forecast', 'openweather'],
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
